@@ -36,7 +36,7 @@ class Utils:
 		return points
 
 	@staticmethod
-	def to_ndarray(points: List[Point] = [], attributes_to_include: List[str] =  ['mz', 'rt', 'intensity']) -> List[List[float]]:
+	def to_ndarray(points: List[Point], attributes_to_include: List[str] =  ['mz', 'rt', 'intensity']) -> List[List[float]]:
 		"""[summary]
 
 		Args:
